from shirkhan.shir_excel.xls import xls
from shirkhan.shir_excel.xlsx import xlsx

"""
excel中xls和xlsx的区别是什么?
excel中xls和xlsx的区别是：
1、xls是复合文档类型的结构，而xlsx的核心结构是XML类型的结构；
2、xls是excel2003及以前版本生成的文件格式，而xlsx是excel2007及以后版本生成的文件格式

其他区别:
1、文件格式不同。xls是一个特有的二进制格式，其核心结构是复合文档类型的结构，而xlsx的核心结构是XML类型的结构，采用的是基于 XML 的压缩方式，使其占用的空间更小。xlsx 中最后一个 x 的意义就在于此。
2、版本不同。xls是excel2003及以前版本生成的文件格式，而xlsx是excel2007及以后版本生成的文件格式。
3、兼容性不同。xlsx格式是向下兼容的，可兼容xls格式。

总结:
xlsx 是Microsoft Office EXCEL 2007/2010/2013/2016/2019文档的扩展名。
xlsx 是从Office2007开始使用的。
xlsx 是用新的基于XML的压缩文件格式取代了其目前专有的默认文件格式，在传统的文件名扩展名后面添加了字母x（即：docx取代doc、.xlsx取代xls等等），使其占用空间更小

----------------------------------------------------------------------------
excel中1个sheet页里能装下多少数据量？
Excel2003 版本的     xls 格式文件可以支持最多  65，536     行数据
Excel2007 以上版本的 xlsx 格式文件可以支持2^20 1，048，576  行数据，最大列数能达到2^14= 16，384

----------------------------------------------------------------------------
python用于读写excel文件的库有很多，除了pandas，还有xlrd、xlwt、openpyxl、xlwings等等。

主要模块：
xlrd库： 从excel中读取数据，支持xls、xlsx
xlwt库： 对excel进行修改操作，不支持对xlsx格式的修改
xlutils库： 在xlw和xlrd中，对一个已存在的文件进行修改
openpyxl： 主要针对xlsx格式的excel进行读取和编辑
xlwings： 对xlsx、xls、xlsm格式文件进行读写、格式修改等操作
xlsxwriter： 用来生成excel表格，插入数据、插入图标等表格操作，不支持读取
Microsoft Excel API： 需安装pywin32，直接与Excel进程通信，可以做任何在Excel里可以做的事情，但比较慢
"""



__version__ = "0.0.23"
__author__ = "shirkhan"

from shirkhan.shir_syllable import *

# utils
from shirkhan.shir_encode_decode import *
from shirkhan.shir_file import *
from shirkhan.shir_string import *
from shirkhan.shir_encryption import *
from shirkhan import shir_csv as csv
from shirkhan import shir_excel as excel
# from shirkhan import shir_wav as wave
# from shirkhan import shir_mp3 as mp3
from shirkhan.shir_email import Mailer as email
# from shirkhan import shir_textgrid as textgrid
# from shirkhan import shir_metadata as metadata
from shirkhan import shir_archive as archive

if __name__ == '__main__':
    pass



from pydub import AudioSegment

'''
分析音频常用linux工具库:
sox
soxi 查看音频详情 metadata

开源pyton 库
pydub
'''


def duration(mp3_path):
    mp3 = AudioSegment.from_mp3(mp3_path)
    return mp3.duration_seconds


def cut_mp3(mp3_path, start_time, end_time, out_path):
    """
    给定的wav按照 start_time 和 end_time 切割并存放在out_path中
    :param mp3_path: 音频路径
    :param start_time: 起始点
    :param end_time:结束点
    :param out_path: 保存的文件路径 xx.wav
    :return:
    """
    song = AudioSegment.from_mp3(mp3_path)
    t1 = start_time * 1000
    t2 = end_time * 1000
    newAudio = song[t1:t2]
    newAudio.export(out_path, format="mp3")
    return True


if __name__ == '__main__':
    pass
